@@ -84,7 +84,7 @@ fn build_exprs(tokens: Vec<CirruLexItem>) -> Result<Vec<Cirru>, String> {
               pointer_stack.push(pointer);
               pointer = vec![];
             }
-            CirruLexItem::Str(s) => pointer.push(Cirru::Leaf(s)),
+            CirruLexItem::Str(s) => pointer.push(Cirru::Leaf(s.into_boxed_str())),
             CirruLexItem::Indent(n) => return Err(format!("unknown indent: {}", n)),
           }
         }
@@ -337,7 +337,7 @@ pub fn parse(code: &str) -> Result<Vec<Cirru>, String> {
 
 pub fn cirru_to_lisp(code: String) -> String {
   match parse(&code) {
-    Ok(tree) => match format_to_lisp(tree) {
+    Ok(tree) => match format_to_lisp(&tree) {
       Ok(s) => s,
       Err(_) => panic!("failed to convert to lisp"),
     },
