@@ -10,7 +10,7 @@ use crate::s_expr;
 /// Cirru uses nested Vecters and Strings as data structure
 #[derive(Clone)]
 pub enum Cirru {
-  Leaf(String),
+  Leaf(Box<str>),
   List(Vec<Cirru>),
 }
 
@@ -154,11 +154,11 @@ impl Cirru {
   pub fn to_lisp(&self) -> Result<String, String> {
     match self {
       Cirru::Leaf(_) => Err(format!("expected list to convert to Lisp, got {}", self)),
-      Cirru::List(xs) => s_expr::format_to_lisp(xs.to_owned()),
+      Cirru::List(xs) => s_expr::format_to_lisp(xs),
     }
   }
 
   pub fn leaf<T: Into<String>>(s: T) -> Self {
-    Cirru::Leaf(s.into())
+    Cirru::Leaf(s.into().into_boxed_str())
   }
 }
